@@ -52,6 +52,7 @@ from lammps_step.nve_step import NVEStep  # noqa: F401
 from lammps_step.tk_nve import TkNVE  # noqa: F401
 
 from lammps_step.nvt import NVT  # noqa: F401
+from lammps_step.nvt import thermostat_metadata  # noqa: F401
 from lammps_step.nvt_parameters import NVT_Parameters  # noqa: F401
 from lammps_step.nvt_step import NVTStep  # noqa: F401
 from lammps_step.tk_nvt import TkNVT  # noqa: F401
@@ -169,11 +170,7 @@ properties = {
         },
     "density":
         {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
+            "calculation": ["npt"],
             "description": "pressure",
             "dimensionality": "scalar",
             "type": "float",
@@ -181,11 +178,7 @@ properties = {
         },
     "density,stderr":
         {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
+            "calculation": ["npt"],
             "description": "stderr of density",
             "dimensionality": "scalar",
             "type": "float",
@@ -193,11 +186,7 @@ properties = {
         },
     "density,tau":
         {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
+            "calculation": ["npt"],
             "description": "autocorrelation time of density",
             "dimensionality": "scalar",
             "type": "float",
@@ -205,11 +194,7 @@ properties = {
         },
     "density,inefficiency":
         {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
+            "calculation": ["npt"],
             "description": "statistical inefficiency of density sampling",
             "dimensionality": "scalar",
             "type": "float",
@@ -217,47 +202,15 @@ properties = {
         },
     "a":
         {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
+            "calculation": ["npt"],
             "description": "cell parameter 'a'",
             "dimensionality": "scalar",
             "type": "float",
             "units": "Å"
         },
-    "b":
-        {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
-            "description": "cell parameter 'b'",
-            "dimensionality": "scalar",
-            "type": "float",
-            "units": "Å"
-        },
-    "c":
-        {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
-            "description": "cell parameter 'c'",
-            "dimensionality": "scalar",
-            "type": "float",
-            "units": "Å"
-        },
     "a,stderr":
         {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
+            "calculation": ["npt"],
             "description": "stderr of cell 'a'",
             "dimensionality": "scalar",
             "type": "float",
@@ -265,11 +218,7 @@ properties = {
         },
     "a,tau":
         {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
+            "calculation": ["npt"],
             "description": "autocorrelation time of cell 'a'",
             "dimensionality": "scalar",
             "type": "float",
@@ -277,16 +226,76 @@ properties = {
         },
     "a,inefficiency":
         {
-            "calculation": [
-                "nve",
-                "nvt",
-                "npt",
-            ],
+            "calculation": ["npt"],
             "description": "statistical inefficiency of cell 'a' sampling",
             "dimensionality": "scalar",
             "type": "float",
             "units": ""
         },
+    "b":
+        {
+            "calculation": ["npt"],
+            "description": "cell parameter 'b'",
+            "dimensionality": "scalar",
+            "type": "float",
+            "units": "Å"
+        },
+    "b,stderr":
+        {
+            "calculation": ["npt"],
+            "description": "stderr of cell 'b'",
+            "dimensionality": "scalar",
+            "type": "float",
+            "units": "K"
+        },
+    "b,tau":
+        {
+            "calculation": ["npt"],
+            "description": "autocorrelation time of cell 'b'",
+            "dimensionality": "scalar",
+            "type": "float",
+            "units": "fs"
+        },
+    "b,inefficiency":
+        {
+            "calculation": ["npt"],
+            "description": "statistical inefficiency of cell 'b' sampling",
+            "dimensionality": "scalar",
+            "type": "float",
+            "units": ""
+        },
+    "c":
+        {
+            "calculation": ["npt"],
+            "description": "cell parameter 'c'",
+            "dimensionality": "scalar",
+            "type": "float",
+            "units": "Å"
+        },
+    "c,stderr":
+        {
+            "calculation": ["npt"],
+            "description": "stderr of cell 'c'",
+            "dimensionality": "scalar",
+            "type": "float",
+            "units": "K"
+        },
+    "c,tau":
+        {
+            "calculation": ["npt"],
+            "description": "autocorrelation time of cell 'c'",
+            "dimensionality": "scalar",
+            "type": "float",
+            "units": "fs"
+        },
+    "c,inefficiency":
+        {
+            "calculation": ["npt"],
+            "description": "statistical inefficiency of cell 'c' sampling",
+            "dimensionality": "scalar",
+            "type": "float",
+            "units": ""
+        },
     "Etot":
         {
             "calculation": [
