@@ -23,13 +23,12 @@ import statsmodels.tsa.stattools as stattools
 
 import lammps_step
 import seamm
-from seamm_util import ureg, Q_, units_class  # noqa: F401
 import seamm_util.printing as printing
 from seamm_util.printing import FormattedText as __
 
 from pymbar import timeseries
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('lammps')
 job = printing.getPrinter()
 printer = printing.getPrinter('lammps')
 
@@ -285,9 +284,10 @@ class LAMMPS(seamm.Node):
         """Run a LAMMPS simulation
         """
 
-        system = self.get_variable('_system')
+        system_db = self.get_variable('_system_db')
+        configuration = system_db.system.configuration
 
-        n_atoms = system.n_atoms()
+        n_atoms = configuration.n_atoms
         if n_atoms == 0:
             self.logger.error('LAMMPS run(): there is no structure!')
             raise RuntimeError('LAMMPS run(): there is no structure!')
@@ -771,6 +771,10 @@ class LAMMPS(seamm.Node):
     def structure_data(self, eex, triclinic=False):
         """Create the LAMMPS structure file from the energy expression"""
         lines = []
+
+        # The terms in the forcefield, and for each a list of forms
+        terms = eex['terms']
+
         lines.append(
             'Structure file for LAMMPS generated by a MolSSI flowchart'
         )
@@ -855,7 +859,6 @@ class LAMMPS(seamm.Node):
                 lines.append(
                     f'{i+1:6d} {index:6d} {x:12.7f} {y:12.7f} {z:12.7f}'
                 )
-            pass
         lines.append('')
 
         lines.append('Masses')
@@ -909,29 +912,31 @@ class LAMMPS(seamm.Node):
             lines.append('')
             lines.append('Bond Coeffs')
             lines.append('')
+
+            use_hybrid = len(terms['bond']) > 1
+
             for counter, parameters in zip(
                 range(1, eex['n_bond_types'] + 1), eex['bond parameters']
             ):
                 form, values, types, parameters_type, real_types = \
                     parameters
                 if form == 'quadratic_bond':
-                    # '{:6d} harmonic {} {}'
-                    lines.append(
-                        '{:6d} {} {}'
-                        .format(counter, values['K2'], values['R0']) +
-                        ' # {}-{} --> {}-{}'.format(
-                            types[0], types[1], real_types[0], real_types[1]
-                        )
+                    function = 'harmonic' if use_hybrid else ''
+                    line = (
+                        f"{counter:6d} {function} "
+                        f"{values['K2']} {values['R0']}"
                     )
                 elif form == 'quartic_bond':
-                    lines.append(
-                        '{:6d} class2 {} {} {} {}'.format(
-                            counter, values['R0'], values['K2'], values['K3'],
-                            values['K4']
-                        ) + ' # {}-{} --> {}-{}'.format(
-                            types[0], types[1], real_types[0], real_types[1]
-                        )
+                    function = 'class2' if use_hybrid else ''
+                    line = (
+                        f"{counter:6d} {function} {values['R0']} "
+                        f"{values['K2']} {values['K3']} {values['K4']}"
                     )
+                line += (
+                    f" # {types[0]}-{types[1]}"
+                    f" --> {real_types[0]}_{real_types[1]}"
+                )
+                lines.append(line)
 
         # angles
         if 'n_angles' in eex and eex['n_angles'] > 0:
@@ -951,31 +956,34 @@ class LAMMPS(seamm.Node):
             lines.append('')
             lines.append('Angle Coeffs')
             lines.append('')
+
+            use_hybrid = len(terms['angle']) > 1
+            quartic_function = (
+                'class2' if 'n_bond-bond_types' in eex else 'quartic'
+            )
+
             for counter, parameters in zip(
                 range(1, eex['n_angle_types'] + 1), eex['angle parameters']
             ):
                 form, values, types, parameters_type, real_types = \
                     parameters
                 if form == 'quadratic_angle':
-                    # '{:6d} harmonic {} {}'
-                    lines.append(
-                        '{:6d} {} {}'
-                        .format(counter, values['K2'], values['Theta0']) +
-                        ' # {}-{}-{} --> {}-{}-{}'.format(
-                            types[0], types[1], types[2], real_types[0],
-                            real_types[1], real_types[2]
-                        )
+                    function = 'harmonic' if use_hybrid else ''
+                    line = (
+                        f"{counter:6d} {function} "
+                        f"{values['K2']} {values['Theta0']}"
                     )
                 elif form == 'quartic_angle':
-                    lines.append(
-                        '{:6d} class2 {} {} {} {}'.format(
-                            counter, values['Theta0'], values['K2'],
-                            values['K3'], values['K4']
-                        ) + ' # {}-{}-{} --> {}-{}-{}'.format(
-                            types[0], types[1], types[2], real_types[0],
-                            real_types[1], real_types[2]
-                        )
+                    function = quartic_function if use_hybrid else ''
+                    line = (
+                        f"{counter:6d} {function} {values['Theta0']} "
+                        f"{values['K2']} {values['K3']} {values['K4']}"
                     )
+                line += (
+                    f" # {types[0]} {types[1]} {types[2]}"
+                    f" --> {real_types[0]} {real_types[1]} {real_types[2]}"
+                )
+                lines.append(line)
 
             # bond-bond coefficients, which must match angles in order & number
             if 'n_bond-bond_types' in eex:
@@ -1057,6 +1065,9 @@ class LAMMPS(seamm.Node):
             lines.append('')
             lines.append('Dihedral Coeffs')
             lines.append('')
+
+            use_hybrid = len(terms['torsion']) > 1
+
             for counter, parameters in zip(
                 range(1, eex['n_torsion_types'] + 1), eex['torsion parameters']
             ):
@@ -1090,27 +1101,22 @@ class LAMMPS(seamm.Node):
                         raise RuntimeError(
                             'LAMMPS cannot handle Phi0 = {}'.format(Phi0)
                         )
-
-                    lines.append(
-                        '{:6d} harmonic {} {} {}'.format(counter, KPhi, d, n) +
-                        ' # {}-{}-{}-{} --> {}-{}-{}-{}'.format(
-                            types[0], types[1], types[2], types[3],
-                            real_types[0], real_types[1], real_types[2],
-                            real_types[3]
-                        )
-                    )
+                    function = 'harmonic' if use_hybrid else ''
+                    line = f'{counter:6d} {function} {KPhi} {d} {n}'
                 elif form == 'torsion_3':
-                    lines.append(
-                        '{:6d} class2 {} {} {} {} {} {}'.format(
-                            counter, values['V1'], values['Phi0_1'],
-                            values['V2'], values['Phi0_2'], values['V3'],
-                            values['Phi0_3']
-                        ) + ' # {}-{}-{}-{} --> {}-{}-{}-{}'.format(
-                            types[0], types[1], types[2], types[3],
-                            real_types[0], real_types[1], real_types[2],
-                            real_types[3]
-                        )
+                    function = 'class2' if use_hybrid else ''
+                    line = (
+                        f"{counter:6d} {function} "
+                        f"{values['V1']} {values['Phi0_1']} "
+                        f"{values['V2']} {values['Phi0_2']} "
+                        f"{values['V3']} {values['Phi0_3']} "
                     )
+                line += (
+                    f' # {types[0]}-{types[1]}-{types[2]}-{types[3]} '
+                    f'--> {real_types[0]}-{real_types[1]}-'
+                    f'{real_types[2]}-{real_types[3]}'
+                )
+                lines.append(line)
 
             # middle bond-torsion_3 coefficients, which must match torsions
             # in order & number
@@ -1839,14 +1845,14 @@ class LAMMPS(seamm.Node):
                     atoms.append(i)
                     atoms.append(j)
                     atoms.append(k)
-                    if 'n_bonds' in eex and eex['n_bonds'] > 0:
-                        for i, j, index in eex['bonds']:
-                            if i in atoms and j in atoms:
-                                bond_types[index] = 1
-                    if 'n_angles' in eex and eex['n_angles'] > 0:
-                        for i, j, k, index in eex['angles']:
-                            if i in atoms and j in atoms and k in atoms:
-                                angle_types[index] = 1
+                if 'n_bonds' in eex and eex['n_bonds'] > 0:
+                    for i, j, index in eex['bonds']:
+                        if i in atoms and j in atoms:
+                            bond_types[index] = 1
+                if 'n_angles' in eex and eex['n_angles'] > 0:
+                    for i, j, k, index in eex['angles']:
+                        if i in atoms and j in atoms and k in atoms:
+                            angle_types[index] = 1
 
         # Fixing bond lengths of X-H bonds...
         if 'n_bonds' in eex and eex['n_bonds'] > 0:
@@ -1888,9 +1894,10 @@ class LAMMPS(seamm.Node):
         """
         self.logger.info("Reading dump file '{}'".format(dumpfile))
 
-        system = self.get_variable('_system')
-        periodicity = system.periodicity
-        n_atoms = system.n_atoms()
+        system_db = self.get_variable('_system_db')
+        configuration = system_db.system.configuration
+        periodicity = configuration.periodicity
+        n_atoms = configuration.n_atoms
 
         section = ''
         section_lines = []
@@ -1984,8 +1991,8 @@ class LAMMPS(seamm.Node):
                 xyz.append([float(x), float(y), float(z)])
 
         if periodicity == 3:
-            system.cell.set_cell(cell)
-        system.atoms.set_coordinates(xyz, fractionals=False)
+            configuration.cell.parameters = (cell)
+        configuration.atoms.set_coordinates(xyz, fractionals=False)
 
     def _add_lammps_citations(self, text, cite=None):
         """Add the two main citations for LAMMPS, getting the version from stdout
